public class Hamster {

  // die Konstanten repraesentieren die vier Richtungen, in die ein
  // Hamster blicken kann
  public final static int NORD = 0;
  public final static int OST  = 1;
  public final static int SUED = 2;
  public final static int WEST = 3;

  // Konstruktor zum Erzeugen eines nicht initialisierten Hamsters
  public Hamster() {}

  // Konstruktor
  // erzeugt und initialisiert einen Hamster
  // reihe:         die Reihe des Territoriums, in der der Hamster erzeugt wird
  // spalte:        die Spalte des Territoriums, in der der Hamster erzeugt wird
  // blickrichtung: die Richtung, in der der Hamster anfangs schaut (siehe
  //                Konstanten)
  // anzahlKoerner: die Anzahl an Koernern, die der Hamster anfangs im
  //                Maul hat
  // HamsterInitialisierungsException: wird geworfen, wenn:
  //   - eine Kachel (reihe/spalte) nicht existiert
  //   - die Kachel (reihe/spalte) durch eine Mauer blockiert ist
  //   - der Wert von blickrichtung nicht zwischen 0 und 3 liegt
  //   - der Wert von anzahlKoerner < 0 ist
  public Hamster(int reihe, int spalte, int blickrichtung, int anzahlKoerner)
    throws HamsterInitialisierungsException {}

  // Konstruktor
  // erzeugt und initialisiert einen Hamster mit den Werten eines bereits 
  // existierenden Hamsters
  // hamster: ein bereits existierender Hamster
  public Hamster(Hamster hamster) {}

  // Methode zur Initialisierung eines Hamsters
  // reihe:         die Reihe des Territoriums, in der der Hamster erzeugt wird
  // spalte:        die Spalte des Territoriums, in der der Hamster erzeugt wird
  // blickrichtung: die Richtung, in der der Hamster anfangs schaut (siehe
  //                Konstanten)
  // anzahlKoerner: die Anzahl an Koernern, die der Hamster anfangs im
  //                Maul hat
  // HamsterInitialisierungsException: wird geworfen, wenn:
  //   - eine Kachel (reihe/spalte) nicht existiert
  //   - die Kachel (reihe/spalte) durch eine Mauer blockiert ist
  //   - der Wert von blickrichtung nicht zwischen 0 und 3 liegt
  //   - der Wert von anzahlKoerner < 0 ist
  // der Aufruf der Methode fuer einen bereits initialisierten Hamster
  // bewirkt nichts
  public void init(int reihe, int spalte, int blickrichtung, int anzahlKoerner)
    throws HamsterInitialisierungsException {}

  // Der aufgerufene Hamster springt auf die in Blickrichtung vor ihm liegende
  // Kachel.
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  // MauerDaException: wird geworfen, wenn die Kachel in Blickrichtung vor dem
  //   Hamster durch eine Mauer blockiert ist oder der Hamster in Blickrichtung
  //   am Rand des Territoriums steht
  public void vor()
    throws HamsterNichtInitialisiertException, MauerDaException {}

  // Der aufgerufene Hamster dreht sich linksum.
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public void linksUm()
    throws HamsterNichtInitialisiertException {}

  // Der aufgerufene Hamster legt ein Korn auf der Kachel ab, auf der er sich
  // gerade befindet.
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  // MaulLeerException: wird geworfen, wenn der Hamster keine Koerner im Maul
  //   hat
  public void gib()
    throws HamsterNichtInitialisiertException, MaulLeerException {}

  // Der aufgerufene Hamster frisst ein Korn auf der Kachel, auf der er sich
  // gerade befindet.
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  // KachelLeerException: wird geworfen, wenn auf der Kachel, auf der sich
  //   der Hamster gerade befindet, kein Korn liegt
  public void nimm()
    throws HamsterNichtInitialisiertException, KachelLeerException {}

  // liefert genau dann true, wenn  sich in Blickrichtung vor dem aufgerufenen
  // Hamster keine Mauer befindet (wenn sich der Hamster in Blickrichtung am
  // Rand des Territoriums befindet, wird false geliefert)
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public boolean vornFrei()
    throws HamsterNichtInitialisiertException { return true; }

  // liefert genau dann true, wenn der aufgerufene Hamster keine Koerner im
  // Maul hat
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public boolean maulLeer()
    throws HamsterNichtInitialisiertException { return true; }

  // liefert genau dann true, wenn auf der Kachel, auf der sich der
  // aufgerufene Hamster gerade befindet, mindestens ein Korn liegt
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public boolean kornDa()
    throws HamsterNichtInitialisiertException { return true; }

  // gibt den uebergebenen String auf den Bildschirm aus
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public void schreib(String zeichenkette)
    throws HamsterNichtInitialisiertException {}

  // gibt den uebergebenen String auf den Bildschirm aus und fordert den
  // Benutzer auf, einen String einzugeben; der eingegebene String wird
  // als Wert geliefert
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public String liesZeichenkette(String aufforderung)
    throws HamsterNichtInitialisiertException { return null; }

  // gibt den uebergebenen String auf den Bildschirm aus und fordert den
  // Benutzer auf, eine Zahl einzugeben; die eingegebene Zahl wird
  // als Wert geliefert (wenn der Benutzer eine ungueltige Zahl eingibt,
  // wird der Wert 0 geliefert)
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public int liesZahl(String aufforderung)
    throws HamsterNichtInitialisiertException { return 0; }

  // liefert die Reihe der Kachel des Territoriums, auf der sich der aufgerufene 
  // Hamster gerade befindet
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public int getReihe()
    throws HamsterNichtInitialisiertException { return 0; }

  // liefert die Spalte der Kachel des Territoriums, auf der sich der aufgerufene 
  // Hamster gerade befindet
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public int getSpalte() 
    throws HamsterNichtInitialisiertException { return 0; }

  // liefert die Blickrichtung, in die der aufgerufene Hamster gerade schaut
  // (gelieferten Werte entsprechen den obigen Konstanten)
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public int getBlickrichtung()
    throws HamsterNichtInitialisiertException { return 0; }

  // liefert die Anzahl der Koerner, die der aufgerufene Hamster gerade im
  // Maul hat
  // HamsterNichtInitialisiertException: wird geworfen, wenn der Hamster noch
  //   nicht initialisiert worden ist
  public int getAnzahlKoerner()
    throws HamsterNichtInitialisiertException { return 0; }

  // liefert den Standard-Hamster
  public static Hamster getStandardHamster() { return null; }

  // liefert die Gesamtzahl an erzeugten und initialisierten
  // Hamstern im Territorium (inkl. dem Standard-Hamster)
  public static int getAnzahlHamster() { return 0; }

  // Methode, die einen Klon des aufgerufenen Hamsters erzeugt und liefert,
  // d.h. die Werte der Attribute des neuen Hamsters sind identisch zu den
  // Werten des aufgerufenen Hamsters.
  // Wenn der aufgerufene Hamster noch nicht initialisiert ist, wird der
  // neu erzeugte Hamster auch nicht initialisiert.
  // (ueberschreibt die entsprechende von der Klasse Object geerbte Methode)
  protected Object clone() { return null; }

  // Methode, die ueberprueft, ob die Werte der Attribute des aufgerufenen Hamsters
  // gleich der Attributwerte des uebergebenen Hamsters sind (zwei nicht
  // initialisierte Hamster sind auch gleich)
  // hamster: muss ein Objekt der Klasse Hamster oder einer davon abgeleiteten
  //          Klasse sein
  // (ueberschreibt die entsprechende von der Klasse Object geerbte Methode)
  public boolean equals(Object hamster) { return true; }

  // Methode, die eine String-Repraesentation der folgenden Art fuer den
  // aufgerufenen Hamster liefert:
  // "Hamster steht auf Kachel (0/0) mit Blickrichtung OST und 2 Koernern im Maul"
  // Wenn der aufgerufene Hamster noch nicht initialisiert ist, wird
  // folgender String geliefert: "Hamster ist nicht initialisiert"
  // (ueberschreibt die entsprechende von der Klasse Object geerbte Methode)
  public String toString() { return null; }

}